@@ -9,7 +9,7 @@ import shutil
 import sys
 import tempfile
 import time
-from typing import ClassVar, List, Optional, Tuple
+from typing import ClassVar, Final, List, Optional, Tuple, Pattern
 
 import aiohttp
 from tqdm import tqdm
@@ -19,24 +19,25 @@ from redbot.core import data_manager
 from .errors import LavalinkDownloadFailed
 
 log = logging.getLogger("red.audio.manager")
-JAR_VERSION = "3.3.1"
-JAR_BUILD = 987
-LAVALINK_DOWNLOAD_URL = (
-    f"https://github.com/Cog-Creators/Lavalink-Jars/releases/download/{JAR_VERSION}_{JAR_BUILD}/"
+JAR_VERSION: Final[str] = "3.3.1"
+JAR_BUILD: Final[int] = 1050
+LAVALINK_DOWNLOAD_URL: Final[str] = (
+    "https://github.com/Cog-Creators/Lavalink-Jars/releases/download/"
+    f"{JAR_VERSION}_{JAR_BUILD}/"
     "Lavalink.jar"
 )
-LAVALINK_DOWNLOAD_DIR = data_manager.cog_data_path(raw_name="Audio")
-LAVALINK_JAR_FILE = LAVALINK_DOWNLOAD_DIR / "Lavalink.jar"
-BUNDLED_APP_YML = pathlib.Path(__file__).parent / "data" / "application.yml"
-LAVALINK_APP_YML = LAVALINK_DOWNLOAD_DIR / "application.yml"
+LAVALINK_DOWNLOAD_DIR: Final[pathlib.Path] = data_manager.cog_data_path(raw_name="Audio")
+LAVALINK_JAR_FILE: Final[pathlib.Path] = LAVALINK_DOWNLOAD_DIR / "Lavalink.jar"
+BUNDLED_APP_YML: Final[pathlib.Path] = pathlib.Path(__file__).parent / "data" / "application.yml"
+LAVALINK_APP_YML: Final[pathlib.Path] = LAVALINK_DOWNLOAD_DIR / "application.yml"
 
-_RE_READY_LINE = re.compile(rb"Started Launcher in \S+ seconds")
-_FAILED_TO_START = re.compile(rb"Web server failed to start. (.*)")
-_RE_BUILD_LINE = re.compile(rb"Build:\s+(?P<build>\d+)")
-_RE_JAVA_VERSION_LINE = re.compile(
+_RE_READY_LINE: Final[Pattern] = re.compile(rb"Started Launcher in \S+ seconds")
+_FAILED_TO_START: Final[Pattern] = re.compile(rb"Web server failed to start. (.*)")
+_RE_BUILD_LINE: Final[Pattern] = re.compile(rb"Build:\s+(?P<build>\d+)")
+_RE_JAVA_VERSION_LINE: Final[Pattern] = re.compile(
     r'version "(?P<major>\d+).(?P<minor>\d+).\d+(?:_\d+)?(?:-[A-Za-z0-9]+)?"'
 )
-_RE_JAVA_SHORT_VERSION = re.compile(r'version "(?P<major>\d+)"')
+_RE_JAVA_SHORT_VERSION: Final[Pattern] = re.compile(r'version "(?P<major>\d+)"')
 
 
 class ServerManager:
@@ -93,17 +94,11 @@ class ServerManager:
     @classmethod
     async def _get_jar_args(cls) -> List[str]:
         (java_available, java_version) = await cls._has_java()
+
         if not java_available:
-            raise RuntimeError("You must install Java 1.8+ for Lavalink to run.")
+            raise RuntimeError("You must install Java 11 for Lavalink to run.")
 
-        if java_version == (1, 8):
-            extra_flags = ["-Dsun.zip.disableMemoryMapping=true"]
-        elif java_version >= (11, 0):
-            extra_flags = ["-Djdk.tls.client.protocols=TLSv1.2"]
-        else:
-            extra_flags = []
-
-        return ["java", *extra_flags, "-jar", str(LAVALINK_JAR_FILE)]
+        return ["java", "-Djdk.tls.client.protocols=TLSv1.2", "-jar", str(LAVALINK_JAR_FILE)]
 
     @classmethod
     async def _has_java(cls) -> Tuple[bool, Optional[Tuple[int, int]]]:
@@ -116,7 +111,7 @@ class ServerManager:
             cls.java_version = None
         else:
             cls._java_version = version = await cls._get_java_version()
-            cls._java_available = (2, 0) > version >= (1, 8) or version >= (8, 0)
+            cls._java_available = (11, 0) <= version < (12, 0)
         return cls._java_available, cls._java_version
 
     @staticmethod
